////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.flickr;

import java.net.URL;
import org.json.JSONObject;
import org.watto.android.Language;


/***********************************************************************************************
Details about a single Flickr friend
***********************************************************************************************/
public class FlickrFriend {

  /** The Flickr user ID **/
  String userID = null; // Custom Column "UserIdData"
  /** The users username **/
  String username = null;
  /** The users real name **/
  String realName = null;
  /** Is this person a friend? **/
  boolean friend = false;
  /** Is this person a family member? **/
  boolean family = false;
  /** The URL to the photo of this user **/
  URL photo = null;
  /** The home city of this user **/
  String homeCity = null;
  /** The number of photos this user has uploaded **/
  long photoCount = 0;
  /** The gender of this user **/
  String gender = null;


  /***********************************************************************************************
  Creates a new Flickr friend from JSON data
  @param friend the JSON data for the friend
  ***********************************************************************************************/
  public FlickrFriend(JSONObject friend){
    toComponent(friend);
  }


  /***********************************************************************************************
  Creates a new Flickr friend
  @param userID the Flickr User ID
  @param username the username of the user
  @param realName the real name of the user
  @param friend whether the user is a friend or not
  @param family whether the user is a family member or not
  ***********************************************************************************************/
  public FlickrFriend(String userID, String username, String realName, boolean friend, boolean family){
    this.userID = userID;
    this.username = username;
    this.realName = realName;
    this.friend = friend;
    this.family = family;
  }


  /***********************************************************************************************
  Gets the gender of the user
  @return the <i>gender</i>
  ***********************************************************************************************/
  public String getGender(){
    return gender;
  }


  /***********************************************************************************************
  Gets the home city of this user
  @return the <i>homeCity</i>
  ***********************************************************************************************/
  public String getHomeCity(){
    return homeCity;
  }


  /***********************************************************************************************
  Gets the URL for the photo of this user
  @return the <i>photo</i> URL
  ***********************************************************************************************/
  public URL getPhoto(){
    return photo;
  }


  /***********************************************************************************************
  Gets the number of photos uploaded by the user
  @return the <i>photoCount</i>
  ***********************************************************************************************/
  public long getPhotoCount(){
    return photoCount;
  }


  /***********************************************************************************************
  Gets the real name of the user
  @return the <i>realName</i>
  ***********************************************************************************************/
  public String getRealName(){
    return realName;
  }


  /***********************************************************************************************
  Gets the user ID of this user
  @return the <i>userID</i>
  ***********************************************************************************************/
  public String getUserID(){
    return userID;
  }


  /***********************************************************************************************
  Gets the username of the user
  @return the <i>username</i>
  ***********************************************************************************************/
  public String getUsername(){
    return username;
  }


  /***********************************************************************************************
  Gets whether the user is a family member or not
  @return the <i>family</i> member flag
  ***********************************************************************************************/
  public boolean isFamily(){
    return family;
  }


  /***********************************************************************************************
  Gets whether the user is a friend or not
  @return the <i>friend</i> flag
  ***********************************************************************************************/
  public boolean isFriend(){
    return friend;
  }


  /***********************************************************************************************
  Sets whether the user is a family member or not
  @param family <b>true</b> if the user is a family member<br />
                <b>false</b> if the user is not a family member
  ***********************************************************************************************/
  public void setFamily(boolean family){
    this.family = family;
  }


  /***********************************************************************************************
  Sets whether the user is a friend or not
  @param friend <b>true</b> if the user is a friend<br />
                <b>false</b> if the user is not a friend
  ***********************************************************************************************/
  public void setFriend(boolean friend){
    this.friend = friend;
  }


  /***********************************************************************************************
  Sets the gender of the user
  @param gender the gender
  ***********************************************************************************************/
  public void setGender(String gender){
    if (gender == null || gender.equals("")) {
      this.gender = null;
    }
    else if (gender.equals("M")) {
      this.gender = Language.get(R.string.gender_male);
    }
    else if (gender.equals("F")) {
      this.gender = Language.get(R.string.gender_female);
    }
    else {
      this.gender = null;
    }
  }


  /***********************************************************************************************
  Sets the home city of this user
  @param homeCity the home city of this user
  ***********************************************************************************************/
  public void setHomeCity(String homeCity){
    if (homeCity != null && homeCity.equals("null")) { // ignore 'null' values
      homeCity = null;
    }
    this.homeCity = homeCity;
  }


  /***********************************************************************************************
  Sets the URL to the photo of this user
  @param iconServer the server that contains the photo
  @param iconFarm the farm that contains the photo
  ***********************************************************************************************/
  public void setPhoto(long iconServer,long iconFarm){
    try {

      if (iconServer > 0 && iconFarm > 0 && userID != null && !(userID.equals(""))) {
        this.photo = new URL("http://farm" + iconFarm + ".static.flickr.com/" + iconServer + "/buddyicons/" + userID + ".jpg");
      }
      else {
        this.photo = new URL("http://www.flickr.com/images/buddyicon.jpg");
      }
    }
    catch (Throwable t) {}
  }


  /***********************************************************************************************
  Sets the URL to the photo of this user
  @param photo the URL to the photo of this user
  ***********************************************************************************************/
  public void setPhoto(URL photo){
    if (photo != null && photo.equals("null")) { // ignore 'null' values
      photo = null;
    }
    this.photo = photo;
  }


  /***********************************************************************************************
  Sets the number of photos uploaded by the user
  @param photoCount the number of photos uploaded
  ***********************************************************************************************/
  public void setPhotoCount(long photoCount){
    this.photoCount = photoCount;
  }


  /***********************************************************************************************
  Sets the real name of the user
  @param realName the real name of the user
  ***********************************************************************************************/
  public void setRealName(String realName){
    this.realName = realName;
  }


  /***********************************************************************************************
  Sets the User ID of this user
  @param userID the User ID of this user
  ***********************************************************************************************/
  public void setUserID(String userID){
    this.userID = userID;
  }


  /***********************************************************************************************
  Sets the username of the user
  @param username the username
  ***********************************************************************************************/
  public void setUsername(String username){
    this.username = username;
  }


  /***********************************************************************************************
  Populates the FoursquareFriend from JSON data
  @param friend the JSON data for the friend
  ***********************************************************************************************/
  public void toComponent(JSONObject friend){
    try {

      setUserID(friend.optString("nsid",""));
      setUsername(friend.optString("username",""));
      setRealName(friend.optString("realname",""));

      String friendFlag = friend.optString("friend","");
      if (friendFlag.equals("1")) {
        setFriend(true);
      }
      else {
        setFriend(false);
      }

      String familyFlag = friend.optString("family","");
      if (familyFlag.equals("1")) {
        setFamily(true);
      }
      else {
        setFamily(false);
      }

    }
    catch (Throwable t) {}

  }

}
