////////////////////////////////////////////////////////////////////////////////////////////////
//                                                                                            //
//                                       WATTO STUDIOS                                        //
//                             Java Code, Programs, and Software                              //
//                                    http://www.watto.org                                    //
//                                                                                            //
//                           Copyright (C) 2004-2010  WATTO Studios                           //
//                                                                                            //
// This program is free software; you can redistribute it and/or modify it under the terms of //
// the GNU General Public License published by the Free Software Foundation; either version 2 //
// of the License, or (at your option) any later versions. This program is distributed in the //
// hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranties //
// of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License //
// at http://www.gnu.org for more details. For updates and information about this program, go //
// to the WATTO Studios website at http://www.watto.org or email watto@watto.org . Thanks! :) //
//                                                                                            //
////////////////////////////////////////////////////////////////////////////////////////////////

package org.watto.program.android.sync.flickr.sync;

import java.lang.reflect.Method;
import org.watto.program.android.sync.flickr.GlobalConstants;
import android.accounts.Account;
import android.accounts.AccountManager;
import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.ContentResolver;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.provider.ContactsContract;


/***********************************************************************************************
Adds a repeating sync process for the <code>Account</code>. The method used depends on the
Android version used by the device.
***********************************************************************************************/
public class SyncIntervalWrapper extends BroadcastReceiver {



  /***********************************************************************************************
  Android 2.2+ only. Uses Reflection to call ContentResolver.addPeriodicSync()
  ***********************************************************************************************/
  @SuppressWarnings("rawtypes")
  public static void addPeriodicSync(ContentResolver resolver,Account account,String authority,Bundle extras,long pollFrequency){
    if (extras == null){
      extras = new Bundle();
    }
    
    // Implemented as a Reflection call, so we can still support Android 2.1
    //resolver.addPeriodicSync(account,authority,extras,pollFrequency);
    
    Method addPeriodicSync = null;
    try {
      // Ask the ContentResolver if the method exists
      Class[] methodParameters = new Class[]{Account.class,String.class,Bundle.class,long.class};
      addPeriodicSync = ContentResolver.class.getMethod("addPeriodicSync", methodParameters );
      
      // If this gets here, the method exists (Android 2.2+)
      
      // Call the method
      try {
        Object[] parameterObjects = new Object[]{account,authority,extras,pollFrequency};
        addPeriodicSync.invoke(resolver,parameterObjects);
      }
      catch (Throwable t){
        // dump thrown in the method
        //t.printStackTrace();
      }
      
      }
    catch (NoSuchMethodException nsme) { 
      // The method doesn't exist (Android <= 2.1)    
      }
    
  }
  
  
  /***********************************************************************************************
  Android <= 2.1 only. Creates a repeating event on the systems' <code>AlarmManager</code> to
  periodically sync the <code>Account</code>
  ***********************************************************************************************/
  public static void addPeriodicSync(Context context,long pollFrequency){
    AlarmManager alarmManager = (AlarmManager)context.getSystemService(Context.ALARM_SERVICE);
    
    Intent intent = new Intent(context, SyncIntervalWrapper.class);
    PendingIntent pendingIntent = PendingIntent.getBroadcast(context, PendingIntent.FLAG_CANCEL_CURRENT, intent, 0);
    alarmManager.setRepeating(AlarmManager.RTC_WAKEUP, System.currentTimeMillis() + (5 * 1000), pollFrequency * 1000, pendingIntent);
  }

  /***********************************************************************************************
  Android <= 2.1 only. Receives a broadcast from a repeating <code>AlarmManager</code> that
  triggers the sync of the account
  ***********************************************************************************************/
  public void onReceive(Context context,Intent intent){
    AccountManager accountManager = AccountManager.get(context);

    Account[] accounts = accountManager.getAccountsByType(GlobalConstants.ACCOUNT_TYPE);
    if (accounts == null || accounts.length < 1) {
      return;
    }
    Account account = accounts[0];
   
    ContentResolver.requestSync(account,ContactsContract.AUTHORITY,new Bundle());
  }
}
